@@ -3,7 +3,5 @@ houses support routines and the command-line dispatchers for carml
 command.
 """
 
-from .dispatch import dispatch
-
-__all__ = ['dispatch']
-__version__ = '0.0.6'
+__all__ = []
+__version__ = '20.0.0'
